# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TimeFilterFastRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bTimeFilterFastRequest.proto\x12)com.igeolise.traveltime.rabbitmq.requests\"\"\n\x06\x43oords\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lng\x18\x02 \x01(\x02\"]\n\x0eTransportation\x12K\n\x04type\x18\x01 \x01(\x0e\x32=.com.igeolise.traveltime.rabbitmq.requests.TransportationType\"\x9f\x08\n\x15TimeFilterFastRequest\x12\x64\n\x10oneToManyRequest\x18\x01 \x01(\x0b\x32J.com.igeolise.traveltime.rabbitmq.requests.TimeFilterFastRequest.OneToMany\x12\x64\n\x10manyToOneRequest\x18\x02 \x01(\x0b\x32J.com.igeolise.traveltime.rabbitmq.requests.TimeFilterFastRequest.ManyToOne\x1a\x89\x03\n\tOneToMany\x12L\n\x11\x64\x65partureLocation\x18\x01 \x01(\x0b\x32\x31.com.igeolise.traveltime.rabbitmq.requests.Coords\x12\x16\n\x0elocationDeltas\x18\x02 \x03(\x11\x12Q\n\x0etransportation\x18\x03 \x01(\x0b\x32\x39.com.igeolise.traveltime.rabbitmq.requests.Transportation\x12P\n\x11\x61rrivalTimePeriod\x18\x04 \x01(\x0e\x32\x35.com.igeolise.traveltime.rabbitmq.requests.TimePeriod\x12\x12\n\ntravelTime\x18\x05 \x01(\x11\x12]\n\nproperties\x18\x06 \x03(\x0e\x32I.com.igeolise.traveltime.rabbitmq.requests.TimeFilterFastRequest.Property\x1a\x87\x03\n\tManyToOne\x12J\n\x0f\x61rrivalLocation\x18\x01 \x01(\x0b\x32\x31.com.igeolise.traveltime.rabbitmq.requests.Coords\x12\x16\n\x0elocationDeltas\x18\x02 \x03(\x11\x12Q\n\x0etransportation\x18\x03 \x01(\x0b\x32\x39.com.igeolise.traveltime.rabbitmq.requests.Transportation\x12P\n\x11\x61rrivalTimePeriod\x18\x04 \x01(\x0e\x32\x35.com.igeolise.traveltime.rabbitmq.requests.TimePeriod\x12\x12\n\ntravelTime\x18\x05 \x01(\x11\x12]\n\nproperties\x18\x06 \x03(\x0e\x32I.com.igeolise.traveltime.rabbitmq.requests.TimeFilterFastRequest.Property\"$\n\x08Property\x12\t\n\x05\x46\x41RES\x10\x00\x12\r\n\tDISTANCES\x10\x01*\xb8\x01\n\x12TransportationType\x12\x14\n\x10PUBLIC_TRANSPORT\x10\x00\x12\x0b\n\x07\x44RIVING\x10\x01\x12 \n\x1c\x44RIVING_AND_PUBLIC_TRANSPORT\x10\x02\x12\x15\n\x11\x44RIVING_AND_FERRY\x10\x03\x12\x0b\n\x07WALKING\x10\x04\x12\x15\n\x11WALKING_AND_FERRY\x10\x07\x12\x0b\n\x07\x43YCLING\x10\x05\x12\x15\n\x11\x43YCLING_AND_FERRY\x10\x06*!\n\nTimePeriod\x12\x13\n\x0fWEEKDAY_MORNING\x10\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'TimeFilterFastRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRANSPORTATIONTYPE._serialized_start=1264
  _TRANSPORTATIONTYPE._serialized_end=1448
  _TIMEPERIOD._serialized_start=1450
  _TIMEPERIOD._serialized_end=1483
  _COORDS._serialized_start=74
  _COORDS._serialized_end=108
  _TRANSPORTATION._serialized_start=110
  _TRANSPORTATION._serialized_end=203
  _TIMEFILTERFASTREQUEST._serialized_start=206
  _TIMEFILTERFASTREQUEST._serialized_end=1261
  _TIMEFILTERFASTREQUEST_ONETOMANY._serialized_start=436
  _TIMEFILTERFASTREQUEST_ONETOMANY._serialized_end=829
  _TIMEFILTERFASTREQUEST_MANYTOONE._serialized_start=832
  _TIMEFILTERFASTREQUEST_MANYTOONE._serialized_end=1223
  _TIMEFILTERFASTREQUEST_PROPERTY._serialized_start=1225
  _TIMEFILTERFASTREQUEST_PROPERTY._serialized_end=1261
# @@protoc_insertion_point(module_scope)
